==> nextcloud-app-contacts-6.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/mn.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Дэлгэрэнгүй",
    "All contacts" : "Бүх харилцагчид",
    "Contacts" : "Харилцагчид",
    "Copy to full name" : "Бүтэн нэр хуулах",
    "Loading …" : "Уншиж байна...",
    "Rename" : "Нэр солих",
    "Delete" : "Устгах",
    "Download" : "Татаж авах",
    "Copied" : "Хуулагдсан",
    "Cannot copy" : "Хуулагдаагүй",
    "Copy link" : "Холбоос хуулах",
    "Share with users or groups" : "Бусдад түгээх",
    "can edit" : "засаж чадна",
    "Add" : "нэмэх",
    "First name" : "Нэр",
    "Last name" : "Овог",
    "Display name" : "Харагдах нэр",
    "Last modified" : "Сүүлд өөрчилсөн",
    "Password protection" : "Password protection",
    "Save" : "Хадгалах",
    "Description" : "Тайлбар",
    "Settings" : "Settings",
    "Cancel" : "болиулах",
    "Upload a new picture" : "Шинэ зураг оруулах",
    "Choose from Files" : "Файлаас сонгох",
    "Download picture" : "Зураг татаж авах",
    "Delete picture" : "Зураг устгах",
    "Invalid image" : "буруу зураг",
    "Name" : "Нэр",
    "Title" : "Цол/Албан тушаал",
    "Select address book" : "Хаягийн бүртгэл сонгох",
    "Address book" : "Хаягийн бүртгэл",
    "No results" : "Үр дүн байхгүй",
    "Pending" : "Хүлээгдэж байгаа",
    "None" : "юу ч үгүй",
    "New contact" : "Шинэ харилцагч",
    "Close" : "Хаах",
    "Import" : "Импорт",
    "Not grouped" : "Багт ороогүй",
    "User" : "Хэрэглэгч",
    "Group" : "Бүлэг",
    "Email" : "Цахим шуудан",
    "Member" : "Гишүүн",
    "Moderator" : "Шалгагч",
    "Admin" : "Админ",
    "Owner" : "Эзэмшигч",
    "Detailed name" : "Дэлгэрэнгүй нэр",
    "Additional names" : "Нэмэлт нэрүүд",
    "Nickname" : "Товч нэр",
    "Notes" : "Тэмдэглэл",
    "Website" : "Цахим хуудас",
    "Location" : "Байршил",
    "Home" : "Гэр",
    "Work" : "Ажил",
    "Other" : "Бусад",
    "Address" : "Хаяг",
    "Post office box" : "Шуудангийн хайрцаг",
    "City" : "Хот",
    "State or province" : "Аймаг",
    "Postal code" : "Шуудангийн код",
    "Country" : "Улс",
    "Birthday" : "Төрсөн өдөр",
    "Date of death" : "Нас барсан огноо",
    "Phone" : "Утас",
    "Mobile" : "Гар утас",
    "Fax" : "Факс",
    "Fax home" : "Гэрийн факс",
    "Fax work" : "Ажлын факс",
    "Manager" : "Менежер",
    "Social network" : "Олон нийтийн сүлжээ",
    "Child" : "хүүхэд",
    "Mother" : "эх",
    "Father" : "эцэг",
    "Parent" : "эцэг эх",
    "Brother" : "ах",
    "Sister" : "эгч",
    "Relative" : "Хамаарал",
    "Friend" : "Найз",
    "Co-worker" : "Хамтран ажиллагч",
    "Gender" : "Хүйс",
    "Female" : "Эмэгтэй",
    "Male" : "Эрэгтэй",
    "Unknown" : "Үл танигдах зүйл",
    "Time zone" : "Цагийн бүс"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-6.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/mn.js <==
OC.L10N.register(
    "contacts",
    {
    "Details" : "Дэлгэрэнгүй",
    "All contacts" : "Бүх харилцагчид",
    "Contacts" : "Харилцагчид",
    "Copy to full name" : "Бүтэн нэр хуулах",
    "Loading …" : "Уншиж байна...",
    "Rename" : "Нэр солих",
    "Delete" : "Устгах",
    "Download" : "Татаж авах",
    "Copied" : "Хуулагдсан",
    "Cannot copy" : "Хуулагдаагүй",
    "Copy link" : "Холбоос хуулах",
    "Share with users or groups" : "Бусдад түгээх",
    "can edit" : "засаж чадна",
    "Add" : "нэмэх",
    "First name" : "Нэр",
    "Last name" : "Овог",
    "Display name" : "Харагдах нэр",
    "Last modified" : "Сүүлд өөрчилсөн",
    "Password protection" : "Password protection",
    "Save" : "Хадгалах",
    "Description" : "Тайлбар",
    "Settings" : "Settings",
    "Cancel" : "болиулах",
    "Upload a new picture" : "Шинэ зураг оруулах",
    "Choose from Files" : "Файлаас сонгох",
    "Download picture" : "Зураг татаж авах",
    "Delete picture" : "Зураг устгах",
    "Invalid image" : "буруу зураг",
    "Name" : "Нэр",
    "Title" : "Цол/Албан тушаал",
    "Select address book" : "Хаягийн бүртгэл сонгох",
    "Address book" : "Хаягийн бүртгэл",
    "No results" : "Үр дүн байхгүй",
    "Pending" : "Хүлээгдэж байгаа",
    "None" : "юу ч үгүй",
    "New contact" : "Шинэ харилцагч",
    "Close" : "Хаах",
    "Import" : "Импорт",
    "Not grouped" : "Багт ороогүй",
    "User" : "Хэрэглэгч",
    "Group" : "Бүлэг",
    "Email" : "Цахим шуудан",
    "Member" : "Гишүүн",
    "Moderator" : "Шалгагч",
    "Admin" : "Админ",
    "Owner" : "Эзэмшигч",
    "Detailed name" : "Дэлгэрэнгүй нэр",
    "Additional names" : "Нэмэлт нэрүүд",
    "Nickname" : "Товч нэр",
    "Notes" : "Тэмдэглэл",
    "Website" : "Цахим хуудас",
    "Location" : "Байршил",
    "Home" : "Гэр",
    "Work" : "Ажил",
    "Other" : "Бусад",
    "Address" : "Хаяг",
    "Post office box" : "Шуудангийн хайрцаг",
    "City" : "Хот",
    "State or province" : "Аймаг",
    "Postal code" : "Шуудангийн код",
    "Country" : "Улс",
    "Birthday" : "Төрсөн өдөр",
    "Date of death" : "Нас барсан огноо",
    "Phone" : "Утас",
    "Mobile" : "Гар утас",
    "Fax" : "Факс",
    "Fax home" : "Гэрийн факс",
    "Fax work" : "Ажлын факс",
    "Social network" : "Олон нийтийн сүлжээ",
    "Child" : "хүүхэд",
    "Mother" : "эх",
    "Father" : "эцэг",
    "Parent" : "эцэг эх",
    "Brother" : "ах",
    "Sister" : "эгч",
    "Relative" : "Хамаарал",
    "Friend" : "Найз",
    "Co-worker" : "Хамтран ажиллагч",
    "Gender" : "Хүйс",
    "Female" : "Эмэгтэй",
    "Male" : "Эрэгтэй",
    "Unknown" : "Үл танигдах зүйл",
    "Time zone" : "Цагийн бүс",
    "Manager" : "Менежер"
},
"nplurals=2; plural=(n != 1);");
